
/*
xpvox copyright (c) 2005 Jan Panteltje

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/


#include "xpvox.h"
#include "audio.h"

FD_xpvox *fdui;

FL_APPEVENT_CB optimize_idle_cb;

time_t beacon_start_time;


int idle_cb(XEvent *ev, void *data)
{
int a;
static int old_tx_button_state = -1;
static int old_playing_flag = -1;
FILE *lfptr = 0; // -Wall
char *ptr;

//fprintf(stderr, "playing_flag=%d\r", playing_flag);

if(auto_transmit_flag)
	{
	if(auto_play_sequence_flag)
		{
		if(! playing_flag)
			{
			if(fl_get_button(fdui -> timed_play_button) == 1)
				{
				start_player(AUTO_PLAY_SOUND);
				}
			}
		}
	}

if(beacon_flag)
	{
	if(time(NULL) - beacon_start_time >= beacon_period_time)
		{
		if(selected_sound >= 0)
			{
			start_player(SELECTED_SOUND);

			beacon_start_time = time(NULL);

			if(debug_flag)
				{
				fprintf(stderr, "beacon activated play_sound_button\n");
				}
			}
		}
	} /* end if beacon flag */

fl_set_slider_value(fdui -> audio_peak_indicator_slider, audio_peak_level);

if(audio_peak_level > -1.0)
	{
	fl_set_object_color(fdui -> audio_peak_indicator_slider, FL_COL1, FL_RED);
	}
else if(audio_peak_level > -6.0)
	{
	fl_set_object_color(fdui -> audio_peak_indicator_slider, FL_COL1, FL_DARKORANGE);
	}
else if(audio_peak_level > -30.0)
	{
	fl_set_object_color(fdui -> audio_peak_indicator_slider, FL_COL1, FL_GREEN);
	}
else
	{
	fl_set_object_color(fdui -> audio_peak_indicator_slider, FL_COL1, FL_YELLOW);
 	}

if(rts_is_on_flag != old_rts_is_on_flag)
	{
	if(log_flag)
		{
		ogettime(weekday, month, &monthday, &hour, &minute, &second, &year);

		lfptr = fopen(log_filename, "a");
		if(! lfptr)
			{
			fprintf(stderr,\
			"xpvox: idle_cb(): WARNING could not open log file %s for append, no logging!.\n",\
			log_filename);

			log_flag = 0;							
			}
		} /* end if log_flag */

	if(rts_is_on_flag)
		{
		if(log_flag)
			{
			if(playing_flag)
				{
				ptr = line_to_filename(player_sound);
				if(! ptr)
				    {
				    fprintf(stderr,\
					"xpvox: idle_cb(): line_to_filename(%d) failed, cannot log play filename.\n",\
					player_sound);
					
					fprintf(lfptr,\
					"%04d %s %02d %02d:%02d:%02d RTS on ?????\n",\
					year, month, monthday, hour, minute, second);
					}
				else
					{
					fprintf(lfptr,\
					"%04d %s %02d %02d:%02d:%02d RTS on %s\n",\
					year, month, monthday, hour, minute, second, ptr);				
					}
				}
			else
				{
				fprintf(lfptr,\
				"%04d %s %02d %02d:%02d:%02d RTS on\n",\
				year, month, monthday, hour, minute, second);
				}
			} /* end if log_flag */

		fl_set_object_color(fdui -> transmit_button, FL_RED, FL_RED);

		fl_set_object_color(fdui -> rts_state_indicator, FL_RED, FL_RED);

		}
	else
		{
		if(log_flag)
			{	
			fprintf(lfptr,\
			"%04d %s %02d %02d:%02d:%02d RTS off\n",\
			year, month, monthday, hour, minute, second);
			}

		fl_set_object_color(fdui -> transmit_button,  FL_DARKORANGE, FL_RED);

		fl_set_object_color(fdui -> rts_state_indicator, FL_COL1, FL_COL1);
		}

	if(log_flag) fclose(lfptr);

	old_rts_is_on_flag = rts_is_on_flag;
	}

a = fl_get_button(fdui -> transmit_button);

if(a != old_tx_button_state)
	{
	if(a) // tx on
		{
		if(! set_rts(serial_device, 1) )
			{
			fprintf(stderr, "xpvox: audio_routine: WARN set_rts(%s, 1) failed\n", serial_device);
			}

		if(play_lead_in_flag) start_player(LEAD_IN_SOUND);

		}
	else // tx off
		{
		fl_redraw_object(fdui -> transmit_button);

		if(play_lead_out_flag) start_player(LEAD_OUT_SOUND);

		if(! set_rts(serial_device, 0) )
			{
			fprintf(stderr, "xpvox: audio_routine: WARN set_rts(%s, 0) failed\n", serial_device);
			}

		}

	old_tx_button_state = a;
	}

if(playing_flag != old_playing_flag)
	{
	if(playing_flag)
		{
		fl_set_object_color(fdui -> play_sound_button, FL_GREEN, FL_GREEN);

		if(! set_rts(serial_device, 1) )
			{
			fprintf(stderr, "xpvox: audio_routine: WARN set_rts(%s, 1) failed\n", serial_device);
			}
		}
	else
		{
		fl_set_object_color(fdui -> play_sound_button, FL_COL1, FL_BLUE);

		if(! transmission_lock_flag)
			{
			if(! set_rts(serial_device, 0) )
				{
				fprintf(stderr, "xpvox: audio_routine: WARN set_rts(%s, 1) failed\n", serial_device);
				}
			}
		}

	old_playing_flag = playing_flag;
	}

if(agc_init_flag)
	{
	fl_set_object_color(fdui -> agc_button, FL_COL1, FL_DARKORANGE);	
	}
else
	{
	fl_set_object_color(fdui -> agc_button, FL_COL1, FL_RED);
	}

return 0;
} /* end function idle_cb */


